@@ -85,6 +85,11 @@ class PrintHandler:
         self.table_line_thickness = 6
         self.pixbuf_table_codebox_vector = pixbuf_table_codebox_vector
         # pixbuf_table_codebox_vector is [ [ "pixbuf"/"table"/"codebox", [offset, pixbuf, alignment] ],... ]
+        # in tables we need to move the title from the last to the first row
+        for element in self.pixbuf_table_codebox_vector:
+            if element[0] == "table":
+                table = element[1][1]
+                table['matrix'].insert(0, table['matrix'].pop())
         print_data = PrintData()
         print_data.text = pango_text
         print_operation = self.get_print_operation()
@@ -196,7 +201,6 @@ class PrintHandler:
                         if inline_pending_height < pixbuf_height: inline_pending_height = pixbuf_height
                     elif self.pixbuf_table_codebox_vector[i][0] == "table":
                         table = self.pixbuf_table_codebox_vector[i][1][1]
-                        table['matrix'].insert(0, table['matrix'].pop()) # let's put the title to first row
                         table_layouts = self.get_table_layouts(context, table)
                         table_grid = self.get_table_grid(table_layouts, table['col_min'])
                         table_height = self.get_table_height_from_grid(table_grid)
@@ -475,6 +479,15 @@ class PrintHandler:
         """Split Long CodeBoxes"""
         codebox_dict = self.pixbuf_table_codebox_vector[idx][1][1]
         original_splitted_pango = codebox_dict['fill_text'].split(cons.CHAR_NEWLINE)
+        for i, element in enumerate(original_splitted_pango):
+            last_close = element.rfind("</span")
+            last_open = element.rfind("<span")
+            if last_close < last_open:
+                non_closed_span = original_splitted_pango[i][last_open:]
+                end_non_closed_span_idx = non_closed_span.find(">")
+                non_closed_span = non_closed_span[:end_non_closed_span_idx+1]
+                original_splitted_pango[i] += "</span>"
+                original_splitted_pango[i+1] = non_closed_span + original_splitted_pango[i+1]
         splitted_pango = []
         codebox_dict_jolly = copy.deepcopy(codebox_dict)
         partial_pango_vec = []
